# Gaelina

A config as folder loader.

## Testing

Install package using: `pip install -e .`

Then run `pytest`

## Installing

Install using pip

> pip intall gaelina

## Contributors

* Emmanuel PLUOT

![coverage](https://gitlab.com/kaeraspace/Kapo/gaelina/badges/master/pipeline.svg)
![coverage](https://gitlab.com/kaeraspace/Kapo/gaelina/badges/master/coverage.svg)
